dnl RCT_WITH_SERVER_PORT
dnl adds a '--with-server-port=' switch to set the
dnl default port for the recoderd to listen to
AC_DEFUN([RCT_WITH_SERVER_PORT],[dnl
AC_ARG_WITH([server-port],
            AS_HELP_STRING([--with-server-port],
                           [set port of recoderd]),
            [ac_cv_server_port=$withval],
            [ac_cv_server_port=no])
AC_CACHE_CHECK([whether a server port was given],
               [ac_cv_server_port],
               [ac_cv_server_port=no])
if test $ac_cv_server_port != "no"; then
  if test "$ac_cv_server_port" -le 0 || test "$ac_cv_server_port" -gt 65536; then
    AC_MSG_ERROR(["$ac_cv_server_port is not a valid TCP port (1-65536)!"])
  fi
  if test "$ac_cv_server_port" -lt 1024; then
    AC_MSG_WARN(["$ac_cv_server_port is a priveliged port (1-1023)! Make sure, recoderd later runs as root!"]);
  fi
  AC_DEFINE_UNQUOTED([DEFAULT_CMD_PORT], [$ac_cv_server_port], [use this port for the recoderd])
fi])

dnl RCT_WITH_DATA_PORT
dnl adds a '--with-data-port=' switch to set the
dnl default port for the data connection of recoderd
AC_DEFUN([RCT_WITH_DATA_PORT],[dnl
AC_ARG_WITH([data-port],
            AS_HELP_STRING([--with-data-port],
                           [set data port used by recoderd]),
            [ac_cv_data_port=$withval],
            [ac_cv_data_port=no])
AC_CACHE_CHECK([whether a data port was given],
               [ac_cv_data_port],
               [ac_cv_data_port=no])
if test $ac_cv_data_port != "no"; then
  if test "$ac_cv_data_port" -le 0 || test "$ac_cv_data_port" -gt 65536; then
    AC_MSG_ERROR(["$ac_cv_data_port is not a valid TCP port (1-65536)!"])
  fi
  if test $ac_cv_server_port != "no" && test "$ac_cv_data_port" -eq "$ac_cv_server_port"; then
    AC_MSG_ERROR(["You cannot use the same port for the server and its data port!"]);
  fi
  if test "$ac_cv_data_port" -lt 1024; then
    AC_MSG_WARN(["$ac_cv_data_port is a priveliged port (1-1023)! Make sure, recoderd later runs as root!"]);
  fi
  AC_DEFINE_UNQUOTED([DEFAULT_DATA_PORT], [$ac_cv_data_port], [use this port as data port for the recoderd])
fi])


dnl RCT_CHECK_IP([IP_ADDRESS])
dnl checks wether the string given is a valid ip address
AC_DEFUN([RCT_CHECK_IP],[dnl
# test if the ip is valid
ip_valid=true
case "$1" in
  .*)
    ip_valid=false
    ;;
  *.)
    ip_valid=false
    ;;
  *)
    part_num=0
    oldifs="$IFS"
    IFS=.
    for ippart in $1; do
      if test $part_num -ge 4; then
        ip_valid=false
        break
      fi
      if test "$ippart" -lt 0 || test "$ippart" -gt 255; then
        ip_valid=false
        break
      fi
      if test $part_num -eq 0 || test $part_num -eq 3; then
        if test "$ippart" -eq 0 || test "$ippart" -eq 255; then
          ip_valid=false
          break
        fi
      fi
      part_num=$(($part_num+1))
    done
    IFS="$oldifs"
    unset oldifs
    if test $part_num -ne 4; then
      ip_valid=false
    fi
    unset part_num
    ;;
esac
# react on validity test
if $ip_valid; then
  :
else
  AC_MSG_ERROR(["\"$1\" is not a valid IP address!"]);
fi
unset ip_valid])

dnl RCT_CHECK_INT([integer])
dnl checks wether the string given is a valid integer number
AC_DEFUN([RCT_CHECK_INT],[dnl
# test if the int is valid
# react on validity test
if test "$1" -ge 0 || test "$1" -le 0; then
  :
else
  AC_MSG_ERROR(["\"$1\" is not a valid Integer!"]);
fi])

dnl RCT_WITH_SERVER_IP
dnl adds a '--with-server-ip=' switch to set the
dnl default server ip to connect by recoderc
AC_DEFUN([RCT_WITH_SERVER_IP],[dnl
AC_ARG_WITH([server-ip],
            AS_HELP_STRING([--with-server-ip],
                           [set the IP of the host running recoderd]),
            [ac_cv_server_ip=$withval],
            [ac_cv_server_ip=no])
AC_CACHE_CHECK([whether a server IP was given],
               [ac_cv_server_ip],
               [ac_cv_server_ip=no])
if test $ac_cv_server_ip != "no"; then
  RCT_CHECK_IP($ac_cv_server_ip)
  AC_DEFINE_UNQUOTED([RECODERD_HOSTNAME], ["$ac_cv_server_ip"], [use this IP to contact the recoderd])
fi])

dnl RCT_WITH_LOCAL_MP_FRAMES
dnl adds a '--with-local-mplayer-frames=' switch to set the
dnl number of frames to be played by local mplayer before recoderc
dnl accepts commands on stdin
AC_DEFUN([RCT_WITH_LOCAL_MP_FRAMES],[dnl
AC_ARG_WITH([local-mplayer-frames],
            AS_HELP_STRING([--with-local-mplayer-frames],
                           [set the number of frames to be played by local mplayer before recoderc accepts commands on stdin]),
            [ac_cv_local_mp_frames=$withval],
            [ac_cv_local_mp_frames=no])
AC_CACHE_CHECK([whether a minimum no of frames was given, before recoderc accepts commands on stdin],
               [ac_cv_local_mp_frames],
               [ac_cv_local_mp_frames=no])
if test $ac_cv_local_mp_frames != "no"; then
  RCT_CHECK_INT($ac_cv_local_mp_frames)
  AC_DEFINE_UNQUOTED([LOCAL_MP_SKIP_FRAMES], [$ac_cv_local_mp_frames], [wait until local mplayer displayed this no. of frames before accepting commands on stdin])
fi])
